PyMagba
=======

This is the first release of PyMagba. It is still in the infancy stage but all the calculations should be correct.
The code has not been cleaned yet, and the documentations are incomplete. Stay tuned. See you on PyMagba 0.2.0!